describeExportTasks method
Retrieve status of one or more export tasks. You can retrieve the status of up to 100 export tasks.
May throw AuthorizationErrorException. May throw InvalidParameterException. May throw InvalidParameterValueException. May throw ServerInternalErrorException. May throw HomeRegionNotSetException.
Parameter exportIds :
One or more unique identifiers used to query the status of an export
request.
Parameter filters :
One or more filters.
-
AgentId- ID of the agent whose collected data will be exported
Parameter maxResults :
The maximum number of volume results returned by
DescribeExportTasks in paginated output. When this parameter
is used, DescribeExportTasks only returns
maxResults results in a single page along with a
nextToken response element.
Parameter nextToken :
The nextToken value returned from a previous paginated
DescribeExportTasks request where maxResults was
used and the results exceeded the value of that parameter. Pagination
continues from the end of the previous results that returned the
nextToken value. This value is null when there are no more
results to return.
Implementation
Future<DescribeExportTasksResponse> describeExportTasks({
List<String>? exportIds,
List<ExportFilter>? filters,
int? maxResults,
String? nextToken,
}) async {
final headers = <String, String>{
'Content-Type': 'application/x-amz-json-1.1',
'X-Amz-Target': 'AWSPoseidonService_V2015_11_01.DescribeExportTasks'
};
final jsonResponse = await _protocol.send(
method: 'POST',
requestUri: '/',
exceptionFnMap: _exceptionFns,
// TODO queryParams
headers: headers,
payload: {
if (exportIds != null) 'exportIds': exportIds,
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
},
);
return DescribeExportTasksResponse.fromJson(jsonResponse.body);
}